@@ -367,10 +367,17 @@ class ImportURI(scoping.ModelLoader):
             return ret
 
         # 2) do we have loaded models?
-        for m in model_repository.local_models.filename_to_model.values():
+        for m in model_repository.local_models:
             ret = self.scope_provider(m, attr, obj_ref)
             if ret:
                 return ret
+
+        # 3) Use builtin models as a fallback if provided
+        if model._tx_metamodel.builtin_models:
+            for m in model._tx_metamodel.builtin_models:
+                ret = self.scope_provider(m, attr, obj_ref)
+                if ret:
+                    return ret
         return None
 
 
@@ -598,6 +605,7 @@ class RelativeName(object):
         lst = self.get_reference_propositions(obj, attr, obj_ref.obj_name)
         if type(lst) is Postponed:
             return lst
+        lst = [x for x in lst if x.name == obj_ref.obj_name]
         if len(lst) > 0:
             return lst[0]
         else:
@@ -667,6 +675,7 @@ class ExtRelativeName(object):
         lst = self.get_reference_propositions(obj, attr, obj_ref.obj_name)
         if type(lst) is Postponed:
             return lst
+        lst = [x for x in lst if x.name == obj_ref.obj_name]
         if len(lst) > 0:
             return lst[0]
         else:
